/**
  *  \file client/scr-mine.cc
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/screens.h"
#include "client/wtile.h"
#include "cpluslib/format.h"
#include "cpluslib/holder.h"
#include "game/global.h"
#include "game/mine.h"
#include "gfx/palette.h"
#include "ui/layout.h"
#include "ui/uiglobal.h"
#include "util/nls.h"
#include "game/planet.h"
#include "client/tiles/objheader.h"
#include "client/tiles/minepassage.h"
#include "client/tiles/mineinfo.h"
#include "int/if/userif.h"
#include "client/widgets/objcontrol.h"
#include "ui/widgets/button.h"

namespace {
    class WMinefieldInfoWindow : public UIWindow {
        ObjectHolder h;
        GObjectType& type;
        void init();
     public:
        WMinefieldInfoWindow(GObjectType& type);
    };
}

/************************** WMinefieldInfoWindow *************************/

WMinefieldInfoWindow::WMinefieldInfoWindow(GObjectType& type)
    : UIWindow(_("Minefield Information"), BLUE_WINDOW, COLOR_GRAY),
      type(type)
{
    init();
}

void
WMinefieldInfoWindow::init()
{
    // VBox
    //   WObjectTypeHeaderTile
    //   WMinefieldInfoTile
    //   WMinefieldPassageTile
    //   HBox
    //     Close GoTo Planet Del <--> H
    // Difference to PCC 1.x: Up/Down are in WObjectTypeHeaderTile
    // FIXME: where are S and I?
    setLayout(UIVBoxLayout::instance5);

    UIGroup& g1 = h.add(new UIGroup(UIHBoxLayout::instance5));

    g1.add(h.add(new UIButton(0, _("Close"), SDLK_ESCAPE)).addStop());
    g1.add(h.add(new UIButton(1, _("Go To"), SDLK_RETURN)).addStop());
    g1.add(h.add(new UISpacer()));

    add(h.add(new WObjectTypeHeaderTile(type)));
    add(h.add(new WMinefieldInfoTile(type)));
    add(h.add(new WMinefieldPassageTile(type)));
    add(g1);
    add(h.add(new WObjectTypeControl(type)));

    pack();
}

void
doMinefieldScreen()
{
    if (global_minefield_type.getCount() == 0)
        return;

    WMinefieldInfoWindow win(global_minefield_type);
    ui_root->centerWidget(win);
    int result = ui_root->runModal(win);
    if (result == 1) {
        // "Go to"
        IntUserInterfaceBinding::getCurrentInstance()->doGoToChart(global_minefield_type.getMinefield().getPos());
    }
}

/** Find nearest minefield. Returns 0 if none found. */
int
findNearestMinefield(GPoint pt)
{
    int found = 0;
    long dist2 = 0;
    bool inside = false;
    const GMinefieldContainer& mfs = getDisplayedTurn().getCurrentUniverse().getMinefields();
    for (GMinefieldContainer::const_iterator i = mfs.begin(); i != mfs.end(); ++i) {
        long ndist2 = distanceSquared(i->getPos(), pt);
        bool ninside = (ndist2 <= i->getUnits());
        /* Pick this minefield, if
           - it's the first one
           - it's closer than our previous choice
           - we're inside it but not inside the previous one */
        if (found <= 0
            || ndist2 < dist2
            || (ninside && !inside))
        {
            found  = i->getId();
            dist2  = ndist2;
            inside = ninside;
        }
    }
    return found;
}
