/**
  *  \file client/tiles/planetfcode.cc
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/planetfcode.h"
#include "int/intglobal.h"
#include "int/value.h"
#include "int/data.h"
#include "game/planet.h"
#include "util/nls.h"
#include "cpluslib/format.h"
#include "ui/widgets/button.h"
#include "ui/uiglobal.h"

/**************************** WPlanetFCodeTile ***************************/

/** \class WPlanetFCodeTile
    \brief Planet FCode & Money Tile

    Displays the planet's FCode and cash. */

WPlanetFCodeTile::WPlanetFCodeTile(GObjectType& type)
    : WObjectTypeObserverTile(GfxPoint(315, 4*font_heights[FONT_NORMAL]), type)
{
    setLayout(RightJustified, 0, false);
    addControl(GfxRect(10, 0,                              20, 20), h.add(new UIButton("F", 'f')));
    addControl(GfxRect(0,  4*font_heights[FONT_NORMAL]-20, 30, 20), h.add(new UIButton("F9", SDLK_F9)));
}

void
WPlanetFCodeTile::drawData(GfxCanvas& can)
{
    const int y = font_heights[FONT_NORMAL];

    GPlanet* p = dynamic_cast<GPlanet*>(getObject());
    if (p != 0 && p->hasPlanetData()) {
        GfxContext ctx;
        ctx.useCanvas(can);
        ctx.useColorScheme(getSkin());
        ctx.useFont(*fonts[FONT_NORMAL]);
        ctx.setColor(UIColor::tc_Static);
        ctx.setSolidBackground();
        outText(ctx, 5, 0, _("Funds:"));
        outText(ctx, 5, y, _("Friendly Code:"));

        ctx.setColor(UIColor::tc_Green);
        outTextF(ctx, 65, 0, 170, format("%d mc", p->getCargo(el_Money)));
        if (p->isFCodeKnown())
            outTextF(ctx, 125, y, 70, p->getFCode());

        string_t comment;
        if (IntValue* v = getPlanetProperties(p->getId())[pp_Comment])
            comment = v->toString(false);
        if (comment.length()) {
            ctx.setColor(UIColor::tc_Yellow);
            outTextF(ctx, 5, 5*y/2, extent.w-35, comment);
        } else {
            ctx.setColor(UIColor::tc_Static);
            outTextF(ctx, 5, 5*y/2, extent.w-35, _("(press [F9] to add a note)"));
        }
    }
}



WNarrowPlanetFCodeTile::WNarrowPlanetFCodeTile(GObjectType& type)
    : WObjectTypeObserverTile(GfxPoint(250, 2*font_heights[FONT_NORMAL]), type)
{ }

void
WNarrowPlanetFCodeTile::drawData(GfxCanvas& can)
{
    GPlanet* p = dynamic_cast<GPlanet*>(getObject());
    if (p == 0)
        return;

    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.useFont(*fonts[FONT_NORMAL]);
    ctx.setColor(UIColor::tc_Static);
    ctx.setSolidBackground();

    int x = 0;
    int y = 0;
    int w = getInnerSize(0, 0).w;

    if (p->isFCodeKnown()) {
        /* FCode is known */
        const char* txt = _("Friendly Code:");
        const int wi = fonts[FONT_NORMAL]->getTextWidth(txt) + font_ems[FONT_NORMAL];
        ctx.setColor(UIColor::tc_Static);
        outText(ctx, x, y, txt);
        ctx.setColor(UIColor::tc_Green);
        outTextF(ctx, x+wi, y, w-wi, p->getFCode());
    }
    y += font_heights[FONT_NORMAL];

    if (p->hasBase()) {
        ctx.setColor(UIColor::tc_Static);
        outTextF(ctx, x, y, w, _("Starbase present"));
    } else if (p->isBuildingBase()) {
        ctx.setColor(UIColor::tc_Green);
        outTextF(ctx, x, y, w, _("Starbase being built"));
    } else {
        ctx.setColor(UIColor::tc_Static);
        outTextF(ctx, x, y, w, _("No starbase"));
    }
}
