/**
  *  \file client/tiles/shipheader.cc
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/shipheader.h"
#include "cpluslib/format.h"
#include "util/nls.h"
#include "game/config.h"
#include "resmgr/resid.h"
#include "game/ship.h"
#include "game/racename.h"
#include "game/team.h"

WShipScreenHeaderTile::WShipScreenHeaderTile(GObjectType& type)
    : WControlScreenHeaderTile(type, bName + bAuto + bCycle + bAdd)
{ }

string_t
WShipScreenHeaderTile::getTitle()
{
    return getObject()->getName();
}

string_t
WShipScreenHeaderTile::getSubtitle()
{
    if (GShip* sh = dynamic_cast<GShip*>(getObject())) {
        /* Format is "(Id #%d, [race] [level] hull)".
           Since format() cannot easily suppress strings conditionally, we
           implement the suppression here. The suppressed parameters still
           appear in the format string, but the %! makes them not show up.
           This has the added benefit of making the format strings for the
           "(ID race hull)" and (ID level hull)" cases different which some
           languages may need. An alternative would have been to use the
           %nn$ syntax to move the argument pointer. */
        int16 level = sh->unit_scores.getScore(ship_score_definitions.lookupScore(ScoreId_ExpLevel));
        const char* fmt = (sh->getRealOwner() != getPlayerId()
                           ? (level >= 0
                              ? _("(Id #%d, %s %s %s)")
                              : _("(Id #%d, %s %!s%s)"))
                           : (level >= 0
                              ? _("(Id #%d, %!s%s %s)")
                              : _("(Id #%d, %!s%!s%s)")));
        return format(fmt)
            << sh->getId()
            << player_racenames.getAdjName(sh->getRealOwner())
            << getExperienceLevelName(level)
            << sh->getHull().getName();
    } else {
        return string_t();
    }
}

ResId
WShipScreenHeaderTile::getPictureId()
{
    if (GShip* sh = dynamic_cast<GShip*>(getObject())) {
        return ResId(res::ship, sh->getHull().getPicture(), sh->getHullId());
    } else {
        return ResId();
    }
}

